@@ -28,4 +28,4 @@ class MeasureFunction(Enum):
     AVG = average
     STDEV = standard_deviation
     MAX = maximum
-    IDENTITY = lambda x: x
\ No newline at end of file
+    IDENTITY = lambda x: x[0]
\ No newline at end of file
